
Changelog
=========

All notable changes to ``explabox`` will be documented in this file.

The format is based on `Keep a Changelog <https://keepachangelog.com/en/1.0.0/>`_\ ,
and this project adheres to `Semantic Versioning <https://semver.org/spec/v2.0.0.html>`_.

`Unreleased <https://git.science.uu.nl/m.j.robeer/explabox/>`_
------------------------------------------------------------------

Added
^^^^^


* README.md
* Sphinx documentation
* Makefile
* License
* Requirements
* Dataset descriptives
* Installation guide
* Text sensitivity tests (\ ``text_sensitivity``\ )
* Text explainability (\ ``text_explainability``\ )
* Model importing (\ ``genbase``\ )
* Dataset handling (\ ``genbase``\ )
* Basic UI (\ ``genbase``\ )
* ``git`` setup

